@@ -38,6 +38,10 @@ class PythonMemcachedInstrumentationTest(TestCase):
         self.cache.get("some_key")
         self.assert_span(operation='get')
 
+    def test_bytes_should_be_converted_to_string(self):
+        self.cache.delete(b"some_key")
+        self.assert_span(operation='delete')
+
     def assert_span(self, operation):
         transaction = execution_context.get_transaction()
         assert transaction
